Prefix

Struct Prefix 

pub struct Prefix {
    pub protocol: AFI,
    pub length: u8,
    pub prefix: Vec<u8>,
}
Represents a generic prefix. For example an IPv4 prefix or IPv6 prefix.

Fields

protocol: AFI

IP version for prefix (v4|v6)

length: u8

Prefix Mask length in bits

prefix: Vec<u8>

Prefix Octets

Implementations

Source

impl Prefix

pub fn masked_octets(&self) -> &[u8]

Get a slice of the prefix octets covered by the prefix mask Useful for encoding the prefix in NLRI